@@ -1,13 +1,13 @@
-!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
-!  Structured Markov Chains Solver      [  SMCSolver  ]       !
-!  Dario Bini, Beatrice Meini, Sergio Steffe'                 !
-!  bini@dm.unipi.it, meini@dm.unipi.it, steffe@dm.unipi.it    !
-!  Dipartimento di Matematica "Leonida Tonelli"               !
-!  Largo Pontecorvo 5                                         !
-!  56127 Pisa                                                 !
-!  Italy                                                      !
-!  Version 2.1 - June  2009                                   !
-!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+     !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+!  Structured Markov Chains Solver      [  SMCSolver  ]                !
+!  Dario Bini, Beatrice Meini, Sergio Steffe'                          !
+!  dario.bini@unipi.it, beatrice.meini@unipi.it, steffe@cs.dm.unipi.it !
+!  Dipartimento di Matematica - Universita' di Pisa                    !
+!  Largo Pontecorvo 5                                                  !
+!  56127 Pisa                                                          !
+!  Italy                                                               !
+!  Version 2.2 - March  2024                                         !
+!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 !
 !
 !
@@ -94,6 +94,7 @@ end function drftmg1
     real(dp),intent(out),dimension(:)  :: p
     ! local variables
     real(dp),dimension(:,:),allocatable :: aa
+    external print_it
     real(dp) :: m, s
     integer  :: n, i, k, ii, j
 !
@@ -261,6 +262,8 @@ subroutine bgth(v,a,b)
     integer :: ldoshift
     integer,dimension(:),allocatable:: ipiv
     real(dp),dimension(:,:,:),allocatable:: ama,tama
+    external print_it
+    external print_it_nolf
 
 !10 FORMAT(1X,"*",\)
 10 FORMAT("*")
@@ -597,6 +600,8 @@ subroutine bgth(v,a,b)
     real(dp),dimension(:),allocatable :: v,w,vgth,uu1
     real(dp),dimension(:,:,:),allocatable:: ama,tama
     integer,dimension(:),allocatable:: ipiv
+    external print_it
+    external print_it_nolf
 !10 FORMAT(1X,"*",\)
 10 FORMAT("*")
     m=size(a0,1)
@@ -1332,6 +1337,7 @@ real(dp),dimension(:,:),allocatable :: aux
 integer,dimension(:),allocatable:: ipiv
 real(dp)::res
 integer :: m,i
+external spect
 m=size(am1,1)
 if (allocated(aux))deallocate(aux)
 if(allocated(ipiv))deallocate(ipiv)
@@ -1378,6 +1384,7 @@ subroutine compute_tauqbd(a,b,c,z)
   real(dp),dimension(:),allocatable::u(:),u1(:),v(:),s(:,:),s1(:,:)
   real(dp)::rp,nwt,r,rq
   integer::i,j
+  external spect
   n=size(a,1)
 if (allocated(u))deallocate(u)
 if (allocated(v))deallocate(v)
@@ -1431,6 +1438,7 @@ subroutine compute_tau(a,z,u,v)
   real(dp),dimension(:),allocatable::u1(:),s(:,:),s1(:,:)
   real(dp)::rp,nwt,r,rq
   integer::i,j
+  external spect
   n=size(a,1);m=size(a,3)
 if (allocated(u1))deallocate(u1)
 if (allocated(s))deallocate(s)
@@ -1512,6 +1520,7 @@ real(dp),dimension(1,n)::vl,vr
 real(dp),dimension(3*n)::work
 real(dp),dimension(n)::wr,wi
 real(dp)::rho
+external DGEEV
 aa=a
 call DGEEV('N','N', N, AA, N, WR, WI, VL, 1, VR,1, WORK, 3*n, info )
 rho=maxval(wr**2+wi**2);
