@@ -1,13 +1,13 @@
-/**************************************************************
- * Structured Markov Chains Solver       [  SMCSolver  ]      *
- * Dario Bini, Beatrice Meini, Sergio Steffe'                 *
- * bini@dm.unipi.it, meini@dm.unipi.it, steffe@dm.unipi.it    *
- * Dipartimento di Matematica "Leonida Tonelli"               *
- * Largo Pontecorvo 5                                         *
- * 56127 Pisa                                                 *
- * Italy                                                      *
- * Version 2.1 - June  2009                                   *
- **************************************************************
+/***************************************************************************
+ * Structured Markov Chains Solver       [  SMCSolver  ]                   *
+ * Dario Bini, Beatrice Meini, Sergio Steffe'                              *
+ * dario.bini@unipi.it, beatrice.meini@unipi.it, steffe@cs.dm.unipi.it     *
+ * Dipartimento di Matematica - Universita' di Pisa                        *
+ * Largo Pontecorvo 5                                                      *
+ * 56127 Pisa                                                              *
+ * Italy                                                                   *
+ * Version 2.2 - March 2024                                             *
+ ***************************************************************************
  *
  *  callbacks.h
  *
@@ -158,19 +158,19 @@ gint delayed_examples_close(void);
 
 
 /* prototypes rw.c */
-GtkWidget* create_fileselection_reada(void);
-GtkWidget* create_fileselection_readb(void);
-GtkWidget* create_fileselection_savea(void);
-GtkWidget* create_fileselection_saveb(void);
-GtkWidget* create_fileselection_g(void);
-GtkWidget* create_fileselection_r(void);
-GtkWidget* create_fileselection_u(void);
-GtkWidget* create_fileselection_gru(void);
-GtkWidget* create_fileselection_pi(void);
-GtkWidget* create_fileselection1 (void);
-GtkWidget* create_dialog_nowritable(void);
-int watch_for_number(int , int , char *);
-GtkWidget* create_fileselection_X(void);
+extern GtkWidget* create_fileselection_reada(void);
+extern GtkWidget* create_fileselection_readb(void);
+extern GtkWidget* create_fileselection_savea(void);
+extern GtkWidget* create_fileselection_saveb(void);
+extern GtkWidget* create_fileselection_g(void);
+extern GtkWidget* create_fileselection_r(void);
+extern GtkWidget* create_fileselection_u(void);
+extern GtkWidget* create_fileselection_gru(void);
+extern GtkWidget* create_fileselection_pi(void);
+extern GtkWidget* create_fileselection1 (void);
+extern GtkWidget* create_dialog_nowritable(void);
+extern int watch_for_number(int , int , char *);
+extern GtkWidget* create_fileselection_X(void);
 
 /* prototypes edit_a.c  */
 void create_edit_a_window(void);
@@ -297,7 +297,7 @@ int is_help_open;    /* 0 = not open 1 = open */
 int is_savepad_open; /* 0 = not open 1 = open */
 int is_running;      /* 0 = not running 1 = running */
 int is_verbose;  /* 1= verbose, 0= not verbose */
-int is_debug;    /* 1= debugging output active on console 0=normal */
+extern int is_debug;    /* 1= debugging output active on console 0=normal */
 int is_timings;  /* 1= internal timing of fortran routines 0=normal */
 int is_situation;    /* 0 = not show 1= show situation bar */
 int is_parameters;   /* 0 = normal 1=to close */
@@ -320,7 +320,7 @@ double beta_in_mant;     /* used bye examples window */
 double beta_in_exp;      /* used bye examples window */
 double beta_in;          /* used bye examples window */
 char digits_to_save[64]; /* string corresponding to the number format chosen to write in files */
-struct parameters_str max[6],min[6],deflt[6],choice[6]; /* default parameters for each algorithm 1,2,3,4,5 */
+extern struct parameters_str max[6],min[6],deflt[6],choice[6]; /* default parameters for each algorithm 1,2,3,4,5 */
 char param_interp_str[9][256], param_err_str[12][256]; /* actual strings used in combo */
 struct pi_parameters_str pi_max,pi_min,pi_deflt,pi_choice; /* default parametres for pi parameters setup */
 GtkWidget  *parameters_entry_maxnc,*parameters_entry_epspi;
@@ -329,9 +329,9 @@ struct goals_str goals_choice,goals_committed;
 struct running_problem_str committed, selected, completed; /* we save data here after successfully allocate the matrices with the data in committed */
 
 /* globals main.c */
-char my_host_name[512];
-char my_prog_name[512];
-int is_smallscr;
+extern char my_host_name[512];
+extern char my_prog_name[512];
+extern int is_smallscr;
 
 /* globals examples.c */
 int  selected_es;  /* which example has been selected by menu in main window */
@@ -339,27 +339,27 @@ int examples_no; /* number of possible examples 1.. 9 */
 struct examples_str es[10];
 
 /* globals rw.c */
-GtkWidget *reada_fs;          /* File Selection Dialog for reading A      */
-GtkWidget *readb_fs;          /* File Selection Dialog for reading B      */
-GtkWidget *savea_fs;          /* File Selection Dialog for saving A       */
-GtkWidget *saveb_fs;          /* File Selection Dialog for saving B       */
-GtkWidget *saveg_fs;          /* File Selection Dialog for saving G       */
-GtkWidget *saver_fs;          /* File Selection Dialog for saving R       */
-GtkWidget *saveu_fs;          /* File Selection Dialog for saving U       */
-GtkWidget *savegru_fs;        /* File Selection Dialog for saving G+R+U   */
-GtkWidget *savepi_fs;         /* File Selection Dialog for saving Pi      */
-GtkWidget *appendsave;        /* File Selection Dialog for saving Notepad  Main Window */
-GtkWidget *readX_fs;          /* File Selection Dialog for reading A      */
+extern GtkWidget *reada_fs;          /* File Selection Dialog for reading A      */
+extern GtkWidget *readb_fs;          /* File Selection Dialog for reading B      */
+extern GtkWidget *savea_fs;          /* File Selection Dialog for saving A       */
+extern GtkWidget *saveb_fs;          /* File Selection Dialog for saving B       */
+extern GtkWidget *saveg_fs;          /* File Selection Dialog for saving G       */
+extern GtkWidget *saver_fs;          /* File Selection Dialog for saving R       */
+extern GtkWidget *saveu_fs;          /* File Selection Dialog for saving U       */
+extern GtkWidget *savegru_fs;        /* File Selection Dialog for saving G+R+U   */
+extern GtkWidget *savepi_fs;         /* File Selection Dialog for saving Pi      */
+extern GtkWidget *appendsave;        /* File Selection Dialog for saving Notepad  Main Window */
+extern GtkWidget *readX_fs;          /* File Selection Dialog for reading A      */
 
-int is_reada_open;      /* 0 = not open 1 = open */
-int is_readb_open;      /* 0 = not open 1 = open */
-int is_savea_open;      /* 0 = not open 1 = open */
-int is_saveb_open;      /* 0 = not open 1 = open */
-int is_saveg_open;      /* 0 = not open 1 = open */
-int is_saver_open;      /* 0 = not open 1 = open */
-int is_saveu_open;      /* 0 = not open 1 = open */
-int is_savegru_open;    /* 0 = not open 1 = open */
-int is_savepi_open;    /* 0 = not open 1 = open */
+extern int is_reada_open;      /* 0 = not open 1 = open */
+extern int is_readb_open;      /* 0 = not open 1 = open */
+extern int is_savea_open;      /* 0 = not open 1 = open */
+extern int is_saveb_open;      /* 0 = not open 1 = open */
+extern int is_saveg_open;      /* 0 = not open 1 = open */
+extern int is_saver_open;      /* 0 = not open 1 = open */
+extern int is_saveu_open;      /* 0 = not open 1 = open */
+extern int is_savegru_open;    /* 0 = not open 1 = open */
+extern int is_savepi_open;    /* 0 = not open 1 = open */
 
 /* globals edit_a.c */
 struct edita_str pea; /* preferences edit a */
@@ -368,10 +368,10 @@ struct edita_str pea; /* preferences edit a */
 struct edita_str peb; /* preferences edit a */
 
 /* globals view_mat.c */
-struct edita_str pview; /* preferences view windows */
-GtkWidget * window_view;
-int is_view_fs_open;         /* 0 not opened, 1 opened */
-GtkWidget  *view_file_read;  /* window for choosing file to read */
-int view_file_activated; /* take note if button file has been selected */
+extern struct edita_str pview; /* preferences view windows */
+extern GtkWidget * window_view;
+extern int is_view_fs_open;         /* 0 not opened, 1 opened */
+extern GtkWidget  *view_file_read;  /* window for choosing file to read */
+extern int view_file_activated; /* take note if button file has been selected */
 
 /****************************/
