@@ -1,13 +1,14 @@
-/**************************************************************
- * Structured Markov Chains Solver       [  SMCSolver  ]      *
- * Dario Bini, Beatrice Meini, Sergio Steffe'                 *
- * bini@dm.unipi.it, meini@dm.unipi.it, steffe@dm.unipi.it    *
- * Dipartimento di Matematica "Leonida Tonelli"               *
- * Largo Pontecorvo 5                                         *
- * 56127 Pisa                                                 *
- * Italy                                                      *
- * Version 2.1 - June  2009                                   *
- **************************************************************
+/***************************************************************************
+ * Structured Markov Chains Solver       [  SMCSolver  ]                   *
+ * Dario Bini, Beatrice Meini, Sergio Steffe'                              *
+ * dario.bini@unipi.it, beatrice.meini@unipi.it, steffe@cs.dm.unipi.it     *
+ * Dipartimento di Matematica - Universita' di Pisa                        *
+ * Largo Pontecorvo 5                                                      *
+ * 56127 Pisa                                                              *
+ * Italy                                                                   *
+ * Version 2.2 - March  2024                                             *
+***************************************************************************
+
  *
  *  edit-a.h - view and edit A  - both callbacks and interfaces
  *
@@ -105,10 +106,10 @@ int is_frozen_i,is_frozen_j; /* values when frozen */
 double is_frozen_a;	     
 
 /* globals interface.c */
-int is_edit_a_open;  /* 0=not open  1=open */
-int is_debug;    /* 1= debugging output active on console 0=normal */
-struct running_problem_str committed;
-struct edita_str pea; /* preferences edit a */
+extern int is_edit_a_open;  /* 0=not open  1=open */
+extern int is_debug;    /* 1= debugging output active on console 0=normal */
+extern struct running_problem_str committed;
+extern struct edita_str pea; /* preferences edit a */
 
 /* globals main.c */
-int is_smallscr;
+extern int is_smallscr;
