@@ -1,13 +1,13 @@
-!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
-!  Structured Markov Chains Solver      [  SMCSolver  ]       !
-!  Dario Bini, Beatrice Meini, Sergio Steffe'                 !
-!  bini@dm.unipi.it, meini@dm.unipi.it, steffe@dm.unipi.it    !
-!  Dipartimento di Matematica "Leonida Tonelli"               !
-!  Largo Pontecorvo 5                                         !
-!  56127 Pisa                                                 !
-!  Italy                                                      !
-!  Version 2.1 - June  2009                                   !
-!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+!  Structured Markov Chains Solver      [  SMCSolver  ]                !
+!  Dario Bini, Beatrice Meini, Sergio Steffe'                          !
+!  dario.bini@unipi.it, beatrice.meini@unipi.it, steffe@cs.dm.unipi.it !
+!  Dipartimento di Matematica - Universita' di Pisa                    !
+!  Largo Pontecorvo 5                                                  !
+!  56127 Pisa                                                          !
+!  Italy                                                               !
+!  Version 2.2 - March  2024                                         !
+!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 !   fcalls.f90   main calls from C to  Fortran computation    !
 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 ! erroflag =0 no errors, 1000 allocation errors, 2000 numeric
@@ -45,6 +45,7 @@ logical ::   dg  ! algorithm flags
 integer ::  ds      ! algorithm flags
 real(dp)::drift 
 integer m         ! for allocating matrices
+external  print_it
 !
 if (debug) write (*,*) "qbd_cr_solve: entering with algflag=",algflag, &
           " goalflag=",goalflag," errorflag=",errorflag,"eps=",errmax,"niter=",itermax
@@ -223,6 +224,7 @@ logical ::  dg  ! algorithm flags
 integer ::  ds ! algorithm flags
 real(dp)::drift    
 integer m         
+external print_it
 !
 !
 if (debug) write (*,*) "qbd_lr_solve: entering with algflag=",algflag,&
@@ -388,6 +390,7 @@ real(dp),dimension(:),allocatable :: v
 ! logical ::  ds    ! do shift
 integer :: method ! 1 natural, 2 traditional, 3 U-based (default)
 integer :: i
+external print_it
 !
 !
 !
@@ -547,6 +550,7 @@ integer errmax    ! input:   eps = epsilon(1.0d0)* 10 ** errmax
 real(dp)::drift,norm1,myeps     !
 real(dp),dimension(:),allocatable :: v
 integer m  
+external print_it
 !
 !
 !
@@ -666,6 +670,7 @@ subroutine mg1_cr_solve(algflag, goalflag,errorflag,errmax,itermax,interpmax,dua
   integer errmax    ! input:   eps = epsilon(1.0d0)* 10 ** errmax
   integer interpmax ! input:   man number of allowed interpolations, default=1  #interpolations= 256*2**interpmax
   integer dual      ! input:   0=automatic, 1=ramaswami, 2=brigth 3= both 4=no
+  external print_it
   real(dp)::norm1,myeps,tau     
   integer:: m, nba,ldual,i
   real(kind(0.d0)),dimension(:,:,:),allocatable:: aa
@@ -877,6 +882,7 @@ integer errmax    ! input:   eps = epsilon(1.0d0)* 10 ** errmax
 integer dual      ! input:   0=automatic, 1=ramaswami, 2=brigth 3= both 4=no
 real(dp)::drift,norm1,myeps,tau     !
 integer m
+external print_it
 !logical ::  ds    ! do shift
 integer :: method ! 1 natural, 2 traditional, 3 U-based (default)
 integer :: i, ldual,nba
@@ -1046,6 +1052,7 @@ integer errorflag ! output:  0= no error else some error did force premature ter
 integer itermax   ! input:   max number of allowed iterations, default=50
 integer errmax    ! input:   eps = epsilon(1.0d0)* 10 ** errmax
 integer dual      ! input:   0=automatic, 1=ramaswami, 2=brigth 3= both 4=no
+external print_it
 real(dp)::drift,norm1,myeps,tau    !
 integer i,m, ldual,nba
  real(kind(0.d0)),dimension(:,:,:),allocatable:: aa
@@ -1157,6 +1164,7 @@ integer itermax   ! input:   max number of allowed iterations, default=50
 integer interpmax ! input:   man number of allowed interpolations, default=1  #interpolations= 256*2**interpmax
 integer errmax    ! input:   eps = epsilon(1.0d0)* 10 ** errmax
 integer dual      ! input:   0=automatic, 1=ramaswami, 2=brigth 3= both
+external print_it
 real(dp)::norm1,myeps, tau
 integer m
 integer:: nba,  i, ldual
@@ -1351,6 +1359,7 @@ integer errorflag ! output:  0= no error else some error did force premature ter
 integer itermax   ! input:   max number of allowed iterations, default=50
 integer errmax    ! input:   eps = epsilon(1.0d0)* 10 ** errmax
 integer dual      ! input:   0=automatic, 1=ramaswami, 2=brigth 3= both
+external print_it
 !
 !
 !
@@ -1398,6 +1407,7 @@ integer errorflag ! output:  0= no error else some error did force premature ter
 integer itermax   ! input:   max number of allowed iterations, default=50
 integer errmax    ! input:   eps = epsilon(1.0d0)* 10 ** errmax
 integer dual      ! input:   0=automatic, 1=ramaswami, 2=brigth 3= both
+external print_it
 real(dp)::drift,norm1,myeps,tau     !
 integer m
 !logical ::  ds    ! do shift
@@ -1592,6 +1602,7 @@ integer errorflag ! output:  0= no error else some error did force premature ter
 integer itermax   ! input:   max number of allowed iterations, default=50
 integer errmax    ! input:   eps = epsilon(1.0d0)* 10 ** errmax
 integer dual      ! input:   0=automatic, 1=ramaswami, 2=brigth 3= both
+external print_it
 real(dp)::drift,norm1,myeps,tau     !
 integer m
 integer :: nba, i, ldual
@@ -1734,6 +1745,7 @@ integer :: epspi    ! input:   myeps = epsilon(1.0d0)* 10 ** epspi
 integer dual      ! input:   0=automatic, 1=ramaswami, 2=brigth 3= both
 real(dp):: myeps  
 integer m,n
+external print_it
 !integer :: m0     ! size of the block B0
 !
 errorflag=0
@@ -1794,6 +1806,7 @@ integer :: epspi    ! input:   myeps = epsilon(1.0d0)* 10 ** epspi
 integer :: bn1flag ! 1 if bn1 is present  0 if not present 
 real(dp):: myeps   
 integer m,n
+external print_it
 !integer :: m0     ! size of the block B0
 !
 finish=.false.
@@ -1853,6 +1866,7 @@ integer :: epspi    ! input:   myeps = epsilon(1.0d0)* 10 ** epspi
 integer :: bn1flag ! 1 if bn1 is present  0 if not present 
 real(dp):: myeps  
 integer m,n
+external print_it
 
 finish=.false.
 info =0
