@@ -1,13 +1,14 @@
-/**************************************************************
- * Structured Markov Chains Solver       [  SMCSolver  ]      *
- * Dario Bini, Beatrice Meini, Sergio Steffe'                 *
- * bini@dm.unipi.it, meini@dm.unipi.it, steffe@dm.unipi.it    *
- * Dipartimento di Matematica "Leonida Tonelli"               *
- * Largo Pontecorvo 5                                         *
- * 56127 Pisa                                                 *
- * Italy                                                      *
- * Version 2.1 - June  2009                                   *
- **************************************************************
+/***************************************************************************
+ * Structured Markov Chains Solver       [  SMCSolver  ]                   *
+ * Dario Bini, Beatrice Meini, Sergio Steffe'                              *
+ * dario.bini@unipi.it, beatrice.meini@unipi.it, steffe@cs.dm.unipi.it     *
+ * Dipartimento di Matematica - Universita' di Pisa                        *
+ * Largo Pontecorvo 5                                                      *
+ * 56127 Pisa                                                              *
+ * Italy                                                                   *
+ * Version 2.2 - March  2024                                             *
+***************************************************************************
+
  *
  *  help.c  - about and  help window interfaces and callbacks
  *
@@ -45,7 +46,7 @@ create_window_about (void)
   gtk_frame_set_shadow_type (GTK_FRAME(frame),GTK_SHADOW_ETCHED_IN);
   gtk_widget_show(frame);
   gtk_container_add(GTK_CONTAINER(dialog_vbox),frame); 
-  label = gtk_label_new("\n\nStructured Markov Chains Solver\n\nDario Bini, Beatrice Meini, Sergio Steffe\'\n\nDipartimento di Matematica \"Leonida Tonelli\"\nUniversita\' di Pisa, Pisa, Italy\n {bini, meini, steffe}@dm.unipi.it\n\nVersion 2.1  June 2009\n\n");
+  label = gtk_label_new("\n\nStructured Markov Chains Solver\n\nDario Bini, Beatrice Meini, Sergio Steffe\'\n\nDipartimento di Matematica - Universita\' di Pisa, Pisa, Italy\n {dario.bini@unipi.it, betrice.meini@unipi.it, steffe@cs.dm.unipi.it\n\nVersion 2.2  March 2024\n\n");
   gtk_widget_show(label);
   gtk_container_add(GTK_CONTAINER(frame),label);
   
@@ -221,6 +222,9 @@ gtk_text_buffer_get_end_iter(bufferm,&enditerm);
 gtk_text_buffer_insert(bufferm,&enditerm,docu15,-1);
 gtk_text_buffer_get_end_iter(bufferm,&enditerm);
 gtk_text_buffer_insert(bufferm,&enditerm,docu16,-1);
+gtk_text_buffer_get_end_iter(bufferm,&enditerm);
+gtk_text_buffer_insert(bufferm,&enditerm,docu17,-1);
+
 
 }
 /*********************************/
