@@ -1,13 +1,14 @@
-/**************************************************************
- * Structured Markov Chains Solver       [  SMCSolver  ]      *
- * Dario Bini, Beatrice Meini, Sergio Steffe'                 *
- * bini@dm.unipi.it, meini@dm.unipi.it, steffe@dm.unipi.it    *
- * Dipartimento di Matematica "Leonida Tonelli"               *
- * Largo Pontecorvo 5                                         *
- * 56127 Pisa                                                 *
- * Italy                                                      *
- * Version 2.1 - June  2009                                   *
- **************************************************************
+/***************************************************************************
+ * Structured Markov Chains Solver       [  SMCSolver  ]                   *
+ * Dario Bini, Beatrice Meini, Sergio Steffe'                              *
+ * dario.bini@unipi.it, beatrice.meini@unipi.it, steffe@cs.dm.unipi.it     *
+ * Dipartimento di Matematica - Universita' di Pisa                        *
+ * Largo Pontecorvo 5                                                      *
+ * 56127 Pisa                                                              *
+ * Italy                                                                   *
+ * Version 2.2 - March  2024                                             *
+***************************************************************************
+
  *
  *  interfaces.h  - most graphical interfaces, except help
  *
@@ -151,105 +152,105 @@ GtkWidget *menuitem_mg1;
 GtkWidget *menuitem_gim1; 
 GtkWidget *menuitem_qbd; 
 
-GtkWidget *noshift_m;
-GtkWidget *simpleshift_m;
-GtkWidget *taushift_m;
-GtkWidget *doubleshift_m;
-GtkWidget *autodual_m;
-GtkWidget *brigthdual_m;
-GtkWidget *ramadual_m;
-GtkWidget *bothdual_m;
-GtkWidget *nodual_m;
+extern GtkWidget *noshift_m;
+extern GtkWidget *simpleshift_m;
+extern GtkWidget *taushift_m;
+extern GtkWidget *doubleshift_m;
+extern GtkWidget *autodual_m;
+extern GtkWidget *brigthdual_m;
+extern GtkWidget *ramadual_m;
+extern GtkWidget *bothdual_m;
+extern GtkWidget *nodual_m;
 
-GtkWidget *cyclicr_basic_m;
-GtkWidget *cyclicr_diagadj_m;
-GtkWidget *logarithmicr_basic_m;
-GtkWidget *logarithmicr_gth_m;
-GtkWidget *funciter_natural_m;
-GtkWidget *funciter_traditional_m;
-GtkWidget *funciter_Ubased_m;
-GtkWidget *invarsubsp_basic_m;
-GtkWidget *invarsubsp_balzer_m;
-GtkWidget *invarsubsp_schur_m;
-GtkWidget *menuitem_newton;
+extern GtkWidget *cyclicr_basic_m;
+extern GtkWidget *cyclicr_diagadj_m;
+extern GtkWidget *logarithmicr_basic_m;
+extern GtkWidget *logarithmicr_gth_m;
+extern GtkWidget *funciter_natural_m;
+extern GtkWidget *funciter_traditional_m;
+extern GtkWidget *funciter_Ubased_m;
+extern GtkWidget *invarsubsp_basic_m;
+extern GtkWidget *invarsubsp_balzer_m;
+extern GtkWidget *invarsubsp_schur_m;
+extern GtkWidget *menuitem_newton;
 
-GtkWidget *funz_starting_m;
+extern GtkWidget *funz_starting_m;
 
-GtkWidget *textview;
-GtkWidget *statusb;
-GtkWidget *window_examples;
-GtkWidget *dimension_m_entry;
-GtkWidget *dimension_n_entry;
-GtkWidget *alpha_entry;
-GtkWidget *beta_entry;
-GtkWidget *howmany_a_entry;
-GtkWidget *statusb_examples;
-GtkWidget *handlebox_s; /* to show the situation of all choice made */
-GtkWidget *label_s1, *label_s2, *label_s3, *label_s4, *label_s5, *label_s6; /* to keep situation up to date */
-GtkWidget * window_parameters; 
-GtkWidget  *parameters_entry_itermax,*parameters_entry_interpmax,*parameters_entry_errmax; /* parameters window entry */
-GtkWidget * window_pi_parameters;
-GtkWidget  *parameters_entry_maxnc,*parameters_entry_epspi; 
-int is_saveg_open;      /* 0 = not open 1 = open */
-int is_about_open;   /* 0 = not open 1 = open */
-int is_help_open;    /* 0 = not open 1 = open */
-int is_savepad_open; /* 0 = not open 1 = open */
-int is_edit_a_open;  /* 0=not open  1=open */
-int is_edit_b_open;  /* 0=not open  1=open */
-int is_view_matrix_open; /* 0=not open  1=open */
-int is_view_pi_open; /* 0=not open  1=open */
-int is_pi_parameters_open; /* 0=not open  1=open */
-int is_readX_open; /* 0=not open  1=open */
-int is_running;      /* 0 = not running 1 = running */
-int is_completed;      /* 1 if computation did complete 0 if it is not completed yet */
-int is_situation;    /* 0 = not show 1= show situation bar */
-int is_verbose;  /* 1= verbose, 0= not verbose */
-int is_debug;    /* 1= debugging output active on console 0=normal */
-int is_timings;  /* 1= internal timing of fortran routines 0=normal */
-int fifosi, fifoin, fifoout, fifomax;                 /* using FIFO to write Notepad in Main Window asyncronously */
-char fifostr[64000][120];                                 /* using FIFO to write Notepad in Main Window asyncronously */
+extern GtkWidget *textview;
+extern GtkWidget *statusb;
+extern GtkWidget *window_examples;
+extern GtkWidget *dimension_m_entry;
+extern GtkWidget *dimension_n_entry;
+extern GtkWidget *alpha_entry;
+extern GtkWidget *beta_entry;
+extern GtkWidget *howmany_a_entry;
+extern GtkWidget *statusb_examples;
+extern GtkWidget *handlebox_s; /* to show the situation of all choice made */
+extern GtkWidget *label_s1, *label_s2, *label_s3, *label_s4, *label_s5, *label_s6; /* to keep situation up to date */
+extern GtkWidget * window_parameters; 
+extern GtkWidget  *parameters_entry_itermax,*parameters_entry_interpmax,*parameters_entry_errmax; /* parameters window entry */
+extern GtkWidget * window_pi_parameters;
+extern GtkWidget  *parameters_entry_maxnc,*parameters_entry_epspi; 
+extern int is_saveg_open;      /* 0 = not open 1 = open */
+extern int is_about_open;   /* 0 = not open 1 = open */
+extern int is_help_open;    /* 0 = not open 1 = open */
+extern int is_savepad_open; /* 0 = not open 1 = open */
+extern int is_edit_a_open;  /* 0=not open  1=open */
+extern int is_edit_b_open;  /* 0=not open  1=open */
+extern int is_view_matrix_open; /* 0=not open  1=open */
+extern int is_view_pi_open; /* 0=not open  1=open */
+extern int is_pi_parameters_open; /* 0=not open  1=open */
+extern int is_readX_open; /* 0=not open  1=open */
+extern int is_running;      /* 0 = not running 1 = running */
+extern int is_completed;      /* 1 if computation did complete 0 if it is not completed yet */
+extern int is_situation;    /* 0 = not show 1= show situation bar */
+extern int is_verbose;  /* 1= verbose, 0= not verbose */
+extern int is_debug;    /* 1= debugging output active on console 0=normal */
+extern int is_timings;  /* 1= internal timing of fortran routines 0=normal */
+extern int fifosi, fifoin, fifoout, fifomax;                 /* using FIFO to write Notepad in Main Window asyncronously */
+extern char fifostr[64000][120];                                 /* using FIFO to write Notepad in Main Window asyncronously */
 
-pthread_t my_thread_main;
+extern pthread_t my_thread_main;
 
-int is_examples_open; /* 0 = not open 1 = open */
-int dimension_m;  /* used bye examples window */
-int dimension_n;  /* used bye examples window */
-int matrix_a_num; /* used bye examples window */
-int matrix_b_num; /* used bye examples window */
+extern int is_examples_open; /* 0 = not open 1 = open */
+extern int dimension_m;  /* used bye examples window */
+extern int dimension_n;  /* used bye examples window */
+extern int matrix_a_num; /* used bye examples window */
+extern int matrix_b_num; /* used bye examples window */
 
 /* double alpha_in_mant;     used bye examples window */
 /* double alpha_in_exp;      used bye examples window */
-double alpha_in;         /*  used bye examples window */
+extern double alpha_in;         /*  used bye examples window */
 /* double beta_in_mant;      used bye examples window */
 /* double beta_in_exp;       used bye examples window */
-double beta_in;          /* used bye examples window */
+extern double beta_in;          /* used bye examples window */
 
-struct algorithms_str algorithms_choice;
-struct goals_str goals_choice;
-struct running_problem_str committed, selected, completed; /* we save data here after successfully allocate the matrices with the data in committed */
-struct edita_str pea,peb;   /* preferences edit_a window */
-struct edita_str pview; /* preferences view windows */
-char digits_to_save[64]; /* string corresponding to the number format chosen to write in files */
+extern struct algorithms_str algorithms_choice;
+extern struct goals_str goals_choice;
+extern struct running_problem_str committed, selected, completed; /* we save data here after successfully allocate the matrices with the data in committed */
+extern struct edita_str pea,peb;   /* preferences edit_a window */
+extern struct edita_str pview; /* preferences view windows */
+extern char digits_to_save[64]; /* string corresponding to the number format chosen to write in files */
 
 /* globals rw.c */
-GtkWidget *saveg_fs;          /* File Selection Dialog for saving G */
-GtkWidget *appendsave;        /* File Selection Dialog for saving Notepad  Main Window */
+extern GtkWidget *saveg_fs;          /* File Selection Dialog for saving G */
+extern GtkWidget *appendsave;        /* File Selection Dialog for saving Notepad  Main Window */
 
-int is_saveg_open;      /* 0 = not open 1 = open */
-int is_saver_open;      /* 0 = not open 1 = open */
-int is_saveu_open;      /* 0 = not open 1 = open */
-int is_savegru_open;      /* 0 = not open 1 = open */
+extern int is_saveg_open;      /* 0 = not open 1 = open */
+extern int is_saver_open;      /* 0 = not open 1 = open */
+extern int is_saveu_open;      /* 0 = not open 1 = open */
+extern int is_savegru_open;      /* 0 = not open 1 = open */
 
 /* globals main.c */
-GtkWidget *window_main;
-int is_smallscr;
+extern GtkWidget *window_main;
+extern int is_smallscr;
 
 /* globals callback.c */
-struct parameters_str max[6],min[6],deflt[6],choice[6]; /* default parametres for each algorithm  */
-char param_interp_str[9][256], param_err_str[12][256]; /* actual strings used in combo */
-struct pi_parameters_str pi_max,pi_min,pi_deflt,pi_choice; /* default parametres for pi parameters setup */
+extern struct parameters_str max[6],min[6],deflt[6],choice[6]; /* default parametres for each algorithm  */
+extern char param_interp_str[9][256], param_err_str[12][256]; /* actual strings used in combo */
+extern struct pi_parameters_str pi_max,pi_min,pi_deflt,pi_choice; /* default parametres for pi parameters setup */
 
 /*globals view_mat.c */
-int fake_dim; /* 4 */
-double fake_matrix[26]; /* fake matrix to load in event of missing data  fortran style indexes 4 x 4 */
+extern int fake_dim; /* 4 */
+extern double fake_matrix[26]; /* fake matrix to load in event of missing data  fortran style indexes 4 x 4 */
 
