@@ -1,13 +1,13 @@
-!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
-!  Structured Markov Chains Solver      [  SMCSolver  ]       !
-!  Dario Bini, Beatrice Meini, Sergio Steffe'                 !
-!  bini@dm.unipi.it, meini@dm.unipi.it, steffe@dm.unipi.it    !
-!  Dipartimento di Matematica "Leonida Tonelli"               !
-!  Largo Pontecorvo 5                                         !
-!  56127 Pisa                                                 !
-!  Italy                                                      !
-!  Version 2.1 - June  2009                                   !
-!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+!  Structured Markov Chains Solver      [  SMCSolver  ]                !
+!  Dario Bini, Beatrice Meini, Sergio Steffe'                          !
+!  dario.bini@unipi.it, beatrice.meini@unipi.it, steffe@cs.dm.unipi.it !
+!  Dipartimento di Matematica - Universita' di Pisa                    !
+!  Largo Pontecorvo 5                                                  !
+!  56127 Pisa                                                          !
+!  Italy                                                               !
+!  Version 2.2 - March 2024                                         !
+!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 !   ponte.f90                                                 !
 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 
@@ -47,6 +47,7 @@ end module ponte_f_f
 subroutine print_it
 use ponte_f_f
 implicit none
+external append_fifo
 !call append_fifo(%ref(trim(wout)//char(10)//char(0)));
 ! some compilers like NAG prefers the following
 call append_fifo((trim(wout)//char(10)//char(0)));
@@ -58,12 +59,14 @@ end subroutine  print_it
 ! to cope with ...
 !
 subroutine print_it_
+external print_it
 call print_it
 end subroutine  print_it_
 
 subroutine print_it_nolf
 use ponte_f_f
 implicit none
+external append_fifo
 !call append_fifo(%ref(trim(wout)//char(0)));
 !  some compilers like NAG prefers the following
 call append_fifo((trim(wout)//char(0)));
@@ -71,6 +74,7 @@ wout=''
 end subroutine  print_it_nolf
 
 subroutine print_it_nolf_
+external print_it_nolf
 call print_it_nolf
 end subroutine  print_it_nolf_
 
