@@ -1,13 +1,14 @@
-/**************************************************************
- * Structured Markov Chains Solver       [  SMCSolver  ]      *
- * Dario Bini, Beatrice Meini, Sergio Steffe'                 *
- * bini@dm.unipi.it, meini@dm.unipi.it, steffe@dm.unipi.it    *
- * Dipartimento di Matematica "Leonida Tonelli"               *
- * Largo Pontecorvo 5                                         *
- * 56127 Pisa                                                 *
- * Italy                                                      *
- * Version 2.1 - June  2009                                   *
- **************************************************************
+/***************************************************************************
+ * Structured Markov Chains Solver       [  SMCSolver  ]                   *
+ * Dario Bini, Beatrice Meini, Sergio Steffe'                              *
+ * dario.bini@unipi.it, beatrice.meini@unipi.it, steffe@cs.dm.unipi.it     *
+ * Dipartimento di Matematica - Universita' di Pisa                        *
+ * Largo Pontecorvo 5                                                      *
+ * 56127 Pisa                                                              *
+ * Italy                                                                   *
+ * Version 2.2 - March 2024                                             *
+***************************************************************************
+
  *
  *  view_pi.c - view Pi quich hack  - both callbacks and interfaces
  *
@@ -465,9 +466,7 @@ void
 draw_view_pi_area(GtkWidget *area, GdkEventExpose *event, gpointer data)
 {
 if(is_debug==1) printf("draw_view_pi_area: begins\n");
-                gdk_draw_rgb_image(area->window,
-                area->style->fg_gc[GTK_WIDGET_STATE (area)],
-                0, 0, HPL,VPL,GDK_RGB_DITHER_NORMAL,((struct viewpi_str *)data)->rgb_view_pivalue,3*(HPL));
+gdk_draw_rgb_image(area->window, area->style->fg_gc[GTK_WIDGET_STATE (area)], 0, 0, HPL,VPL,GDK_RGB_DITHER_NORMAL,((struct viewpi_str *)data)->rgb_view_pivalue,3*(HPL));
 if(is_debug==1) printf("draw_view_pi_area: ends\n");
 }
 /*********************************/
