@@ -1,13 +1,14 @@
-/**************************************************************
- * Structured Markov Chains Solver       [  SMCSolver  ]      *
- * Dario Bini, Beatrice Meini, Sergio Steffe'                 *
- * bini@dm.unipi.it, meini@dm.unipi.it, steffe@dm.unipi.it    *
- * Dipartimento di Matematica "Leonida Tonelli"               *
- * Largo Pontecorvo 5                                         *
- * 56127 Pisa                                                 *
- * Italy                                                      *
- * Version 2.1 - June  2009                                   *
- **************************************************************
+/***************************************************************************
+ * Structured Markov Chains Solver       [  SMCSolver  ]                   *
+ * Dario Bini, Beatrice Meini, Sergio Steffe'                              *
+ * dario.bini@unipi.it, beatrice.meini@unipi.it, steffe@cs.dm.unipi.it     *
+ * Dipartimento di Matematica - Universita' di Pisa                        *
+ * Largo Pontecorvo 5                                                      *
+ * 56127 Pisa                                                              *
+ * Italy                                                                   *
+ * Version 2.2 - March 2024                                             *
+***************************************************************************
+
  *
  *  view_pi.h - view pi vector  - both callbacks and interfaces
  *
@@ -37,13 +38,13 @@ void read_matpi_(int *, int *,double *);
 int HPL, VPL; /* drawing area dimensions */
 
 /* globals main.c */
-int is_debug;
+extern int is_debug;
 
 /* globals interface.c */
-struct running_problem_str  completed; /* we save data here after successfully allocate the matrices with the data in committed */
+extern struct running_problem_str  completed; /* we save data here after successfully allocate the matrices with the data in committed */
 
 /* globals main.c */
-GtkWidget *window_main;       /* main window */
-int is_smallscr;
+extern GtkWidget *window_main;       /* main window */
+extern int is_smallscr;
 
 /*********************************************/
